## Change Log

### v0.0.15 (2019/11/11)
- Support for HATEOAS pagination for orders using `get_orders`

### v0.0.14 (2019/10/23)
- Support for HATEOAS pagination for transactions using `get_transactions`

### v0.0.13 (2019/09/25)
- Support for reports APIs: `get_reports`, `create_report`

### v0.0.12 (2018/09/14)
- Support for EU datacenter (and ST env).

### v0.0.10 (2017/08/28)
- Support for `delete_catalog`, `get_hook`, `delete_hook` endpoints.

### v0.0.8 (2017/08/27)
- Export the correct `poynt` package.

### v0.0.6 (2017/08/27)
- Support for `get_store` endpoint.

### v0.0.5 (2017/08/27)
- Support for sending cloud messages to terminals: `send_raw_cloud_message` and `send_cloud_message` endpoints.
- Support for `create_catalog`, `create_full_catalog`, `update_catalog`, `create_category`, `lookup_categories`, `delete_category`, `update_category`, `get_products_summary`, `create_product`, `delete_product`, `update_product`, `create_tax`, `delete_tax`, `update_tax` endpoints.

### v0.0.4 (2017/08/27)
- Support for `get_orders`, `get_order`, `get_transactions`, `get_transaction`, `get_business_users`, `get_business_user`, `get_customers`, `get_customer`, `get_catalogs`, `get_catalog`, `get_full_catalog`, `get_category`, `get_products`, `lookup_products`, `get_product`, `get_taxes`, `get_tax`, `get_hooks`, `create_hook` endpoints.

### v0.0.1 (2017/08/27)
- Initial commit.
- Support authentication using application private key.
- Support `get_business` endpoint.
